@@ -2,6 +2,6 @@ package Test::Schema::ResultSet::Artist;
 
 use base qw/DBIx::Class::ResultSet/;
 
-__PACKAGE__->load_components('Helper::ResultSet::WindowFunctions');
+__PACKAGE__->load_components('Helper::WindowFunctions');
 
 1;
